**********************************************************************************
* Adding information on yearly and nation-specific at-risk-of-poverty thresholds *
*                   to the longitudinal EU-SILC data                             *
**********************************************************************************

* Version 2
* STATA Command Syntax File
* Stata Version 16.1

* (c) GESIS 2021-03-18
* GESIS - Leibniz Institute for the Social Sciences
* German Microdata Lab 
* Barbara Lange; Alexander Mack, Valentina Ponomarenko
* http://www.gesis.org/en/institute/
*
* Contact: 

********************************************************************************
* UPDATE: Version 2 now requires only to insert path and file name in the      *
* configuration section. No other adaptations in the syntax are necessary.     *
********************************************************************************

/*
The following dofile adds information on the nation- and year-specific at-risk-
of-poverty thresholds to EU-SILC longitudinal data of year T.

It makes use of the representativeness of the cross-sectional EU-SILC data (year T, 
T-1, T-2, and T-3) and extracts the necessary information for calculating the 
prevalent at-risk-of-poverty thresholds (40, 50, 60, and 70% of the median 
equivalised total disposable household income).

These thresholds are merged to the panel file of year T, where each household's
total disposable household income is calculated and used to create a poverty
indicator at the end.

It requires that the D, R, H, and P file of the cross-sectional data are stored
in one folder for each year (T, T-1, T-2, and T-3); they same goes for the
longitudinal data. Please indicate these paths below in the globals.
Also, the naming of the data files should be checked; Stata will give you an 
error message in case it could not find the respective file.
*/

clear
set more off

* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - ;
* START CONFIGURATION SECTION

* Indicate the data file path of the longitudinal file
* For example "C:/User/EU-SILC/PANEL"  

global input_panel "INPUT_PANEL_PATH"			

* Indicate the data file paths of the corresponding cross-sectional files. 
* Please notice: t corresponds to the year of the longitudinal file. 
*                t1 corresponds to year-1, t2 to year-2, t3 to year-3    

global input_cross_t  "INPUT_CROSS_T_PATH"			
global input_cross_t1 "INPUT_CROSS_T1_PATH"			
global input_cross_t2 "INPUT_CROSS_T2_PATH"			
global input_cross_t3 "INPUT_CROSS_T3_PATH"			

* Indicate the file names (without their path) of the D, R, H, and P-files 
* for the panel file and all cross-sectional waves

global panel_dfile "PANEL_DFILE" //D file of longitudinal data of year T
global panel_rfile "PANEL_RFILE" //R file of longitudinal data of year T
global panel_hfile "PANEL_HFILE" //H file of longitudinal data of year T
global panel_pfile "PANEL_PFILE" //P file of longitudinal data of year T

global cross_t_dfile "CROSS_T_DFILE" //D file of cross-sec. data of year T
global cross_t_rfile "CROSS_T_RFILE" //R file of cross-sec. data of year T
global cross_t_hfile "CROSS_T_HFILE" //H file of cross-sec. data of year T
global cross_t_pfile "CROSS_T_PFILE" //P file of cross-sec. data of year T

global cross_t1_dfile "CROSS_T1_DFILE" //D file of cross-sec. data of year T-1
global cross_t1_rfile "CROSS_T1_RFILE" //R file of cross-sec. data of year T-1
global cross_t1_hfile "CROSS_T1_HFILE" //H file of cross-sec. data of year T-1
global cross_t1_pfile "CROSS_T1_PFILE" //P file of cross-sec. data of year T-1

global cross_t2_dfile "CROSS_T2_DFILE" //D file of cross-sec. data of year T-2
global cross_t2_rfile "CROSS_T2_RFILE" //R file of cross-sec. data of year T-2
global cross_t2_hfile "CROSS_T2_HFILE" //H file of cross-sec. data of year T-2
global cross_t2_pfile "CROSS_T2_PFILE" //P file of cross-sec. data of year T-2

global cross_t3_dfile "CROSS_T3_DFILE" //D file of cross-sec. data of year T-3
global cross_t3_rfile "CROSS_T3_RFILE" //R file of cross-sec. data of year T-3
global cross_t3_hfile "CROSS_T3_HFILE" //H file of cross-sec. data of year T-3
global cross_t3_pfile "CROSS_T3_PFILE" //P file of cross-sec. data of year T-3

* Indicate the data file path where extractions of the files and the resulting data file for poverty thresholds should be saved

global output "OUTPUT_PATH"

* Indicate the data file name of final file containing thresholds 
global stata_file "STATA_FILENAME"

* END CONFIGURATION SECTION
* Nothing should be changed below this line ;
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - ;

foreach i in t t1 t2 t3 {
	
	*Extracting information from the different cross-sectional files
	use "${input_cross_`i'}/${cross_`i'_dfile}", clear
	rename (DB010 DB020 DB030) (year country hhid)
	keep year country hhid
	sort year country hhid
	save "$output/`i'dfile_cross.dta",replace

	use "${input_cross_`i'}/${cross_`i'_rfile}", clear
	rename (RB010 RB020 RB030 RX030) (year country pid hhid)
	keep year country pid hhid RB050 RB080 RX020
	sort year country hhid pid
	save "$output/`i'rfile_cross.dta",replace

	use "${input_cross_`i'}/${cross_`i'_hfile}", clear
	rename (HB010 HB020 HB030) (year country hhid)
	keep year country hhid HY020 
	sort year country hhid
	save "$output/`i'hfile_cross.dta",replace

	use "${input_cross_`i'}/${cross_`i'_pfile}", clear
	rename (PB010 PB020 PB030 PX030) (year country pid hhid)
    keep year country pid hhid PY080G
	sort year country hhid pid
	save "$output/`i'pfile_cross.dta",replace
	
	* Merging the cross-sectional files
	use "$output/`i'rfile_cross.dta", clear
	sort year country hhid pid
	merge m:1 year country hhid using "$output/`i'dfile_cross.dta"
	drop _merge

	sort year country hhid pid
	merge m:1 year country hhid using "$output/`i'hfile_cross.dta"
	drop _merge

	sort year country hhid pid
	merge 1:1 year country hhid pid using "$output/`i'pfile_cross.dta"
	drop _merge

	* Calculating poverty thresholds & storing all country codes in a global
	local varlist country
	sort `varlist'
	tempvar names
	qui: gen `names'=1 if `varlist'[_n]!=`varlist'[_n-1]
	sort `names' `varlist'
	qui: count if `names'==1
	local nrvalues=r(N)
	global countries
	local counter=1
	while `counter'<=`nrvalues' {
		local value1=`varlist'[`counter']
		local value2=`varlist'[`counter'-1]
		if "`value1'"!="`value2'" {
			global countries ${countries} `value1'
		}
		local counter=`counter'+1
	}
	global ncountries=wordcount("${countries}")
	display "${countries}"
	display "number of countries in datafile: " $ncountries

	gen int age = RX020
	replace age = year-RB080 - 1 if RX020==.

	********************************************************************************************
	* Pensions received from individual private plans (other than those covered under ESSPROS) * 
	* (PY080G)/(PY080N) are treated as a component of property income, and should be included  *
	* in the total disposable household income (HY020).                                        *  
	* From EU-SILC 2011 onwards, PY080G is automatically included in the computation of HY020, *
	* so it is preferable to add it everywhere to make data comparable.                        *
	********************************************************************************************

	if year<2011 {
		bysort country hhid: egen sum080=sum(PY080G)
		gen hydisp=(HY020+sum080)
	}
	else gen hydisp=HY020

	gen byte child=.
	replace child=1 if age<14
	replace child=0 if age>=14

	gen byte adult=.
	replace adult=1 if age>=14
	replace adult=0 if age<14

	bysort country hhid: egen hhnbr_child = sum(child)
	bysort country hhid: egen hhnbr_adult = sum(adult)
	gen hhnbr_pers = hhnbr_child + hhnbr_adult

	gen float eqs=.
	replace eqs= 1+(hhnbr_adult -1)*0.5 + hhnbr_child * 0.3 if hhnbr_adult>=1
	replace eqs= 1+(hhnbr_child -1)* 0.3 if hhnbr_adult<1

	gen hystd=hydisp/eqs

	forvalues y = 4(1)7 {
		
		gen thresh`y'0=.
			foreach ctry of global countries {
			qui: sum hystd [aw=RB050] if country=="`ctry'", de
			replace thresh`y'0=0.`y'*r(p50) if country=="`ctry'"
		}
	}

	* Save the data with one observation per country only, only containing the thresholds 
	* and necessary identifiers (year and country)
	bysort year country: gen countryrank=_n
	drop if countryrank!=1
	list country thresh40 thresh50 thresh60 thresh70
	keep year country thresh40 thresh50 thresh60 thresh70
	save "$output/threshold`i'_cross.dta", replace
}

*Append the cross-sectional data based thresholds for all years
use "$output/thresholdt_cross.dta", clear
append using "$output/thresholdt1_cross.dta"
append using "$output/thresholdt2_cross.dta"
append using "$output/thresholdt3_cross.dta"

sort year country
save "$output/4yr_cross_thresholds.dta", replace

*********************************************************************

/*
The saved 4-year threshold file can be merged to any of the panel files (year T)
using the m:1 merge command and the identifiers 'year' and 'country'.
Please rename these identifiers in the respective panel data set accordingly.

To generate a poverty dummy indicating if a household falls below the respective
poverty threshold or not, it would be preferable to use the same calculation of 
household incomes as for the computation of the thresholds in the cross-sectional
data files. This requires a merged panel file including the following information:
Variables: RX020, RB080, PY080G, HY020.

Please find an example of merging the panel files, merging the 4-year threshold 
file and creating the poverty dummy for the 60% threshold below.
*/

*Preparing and merging the panel files of year T
cd $input_panel
use "$panel_dfile", clear

rename (DB010 DB020 DB030) (year country hhid)

keep year country hhid
sort year country hhid

save $output/dfile_panel, replace

use "$panel_rfile", clear

rename (RB010 RB020 RB040 RB030) (year country hhid pid)

keep year country hhid pid RX020 RB080
sort year country hhid pid

save $output/rfile_panel, replace

use "$panel_hfile", clear

rename (HB010 HB020 HB030) (year country hhid)

keep year country hhid HY020 
sort year country hhid

save $output/hfile_panel, replace

use "$panel_pfile", clear

rename (PB010 PB020 PB030 PX030) (year country pid hhid)

keep year country hhid pid PY080G
sort year country hhid pid

save $output/pfile_panel, replace

use $output/rfile_panel, clear
sort year country hhid 
merge m:1 year country hhid using $output/dfile_panel
keep if _merge==3
drop _merge

sort year country hhid pid
merge m:1 year country hhid using $output/hfile_panel
keep if _merge==3
drop _merge

sort year country hhid pid
merge 1:1 year country hhid pid using $output/pfile_panel
drop _merge

sort year country hhid pid

save $output/allfiles_panel, replace

*Merging the thresholds computed on basis of the cross-sectional data files of year T, T-1, T-2 and T-3
merge m:1 year country using $output/4yr_cross_thresholds.dta
drop if _merge==2
drop _merge
lab var thresh40 "At-risk-of-poverty threshold (40% of median equivalised income)"
lab var thresh50 "At-risk-of-poverty threshold (50% of median equivalised income)"
lab var thresh60 "At-risk-of-poverty threshold (60% of median equivalised income)"
lab var thresh70 "At-risk-of-poverty threshold (70% of median equivalised income)"

gen int age = RX020
replace age = year-RB080 - 1 if RX020==.

if year<2011 {
	bysort year country hhid: egen sum080=sum(PY080G)
	gen hydisp=(HY020+sum080)
}
else gen hydisp=HY020

gen byte child=.
replace child=1 if age<14
replace child=0 if age>=14

gen byte adult=.
replace adult=1 if age>=14
replace adult=0 if age<14

bysort year country hhid: egen hhnbr_child = sum(child)
bysort year country hhid: egen hhnbr_adult = sum(adult)
gen hhnbr_pers = hhnbr_child + hhnbr_adult

gen float eqs=.
replace eqs= 1+(hhnbr_adult -1)*0.5 + hhnbr_child * 0.3 if hhnbr_adult>=1
replace eqs= 1+(hhnbr_child -1)* 0.3 if hhnbr_adult<1

gen hystd=hydisp/eqs
keep year country pid hhid RB080 RX020 HY020 PY080G thresh40 thresh50 thresh60 thresh70 hystd
label variable hystd "Equivalised total disposable household income"

*Poverty dummies by thresholds 
forvalues i= 4(1)7 {
	gen arop`i'0=.
	replace arop`i'0=1 if hystd<thresh`i'0
	replace arop`i'0=0 if hystd>=thresh`i'0
	lab var arop`i'0 "Poverty indicator (`i'0% threshold)"
}

save ${output}/${stata_file}, replace

* Remove files that have been used in the process, but are not needed.
foreach i in t t1 t2 t3 {
	erase ${output}/`i'dfile_cross.dta
	erase ${output}/`i'rfile_cross.dta
	erase ${output}/`i'hfile_cross.dta
	erase ${output}/`i'pfile_cross.dta
	erase ${output}/threshold`i'_cross.dta
}

foreach f in d r p h {
	erase ${output}/`f'file_panel.dta
}

erase ${output}/allfiles_panel.dta